@@ -14,10 +14,10 @@ import argparse
 import re
 import sys
 
-from deepops import deepmerge
+from deepops import deepmerge, deepget
 import yaml
 
-from .ios import CiscoIOSConfig, CiscoIOSDiffConfig
+from net_contextdiff.ios import CiscoIOSConfig, CiscoIOSDiffConfig
 
 
 
@@ -216,6 +216,14 @@ parser.add_argument(
     help="dump the differences across all compared files as a YAML "
          "tree - this is useful for using in an exclude file")
 
+parser.add_argument(
+    "-S", "--subtree-dump-filter",
+    metavar="key",
+    nargs="*",
+    default=[],
+    help="limit dump options to subtree of configuration dictionary "
+         "with a path specified as list of keys")
+
 parser.add_argument(
     "-P", "--debug-parser",
     action="count",
@@ -287,6 +295,7 @@ dump_rules = args.dump_rules
 dump_config = args.dump_config
 dump_diff = args.dump_diff
 dump_diff_tree = args.dump_diff_tree
+subtree_dump_filter = args.subtree_dump_filter
 debug_parser = args.debug_parser
 debug_convert = args.debug_convert
 from_filename = args.from_filename
@@ -368,7 +377,8 @@ elif len(devicenames) > 1:
 
 # create the diff object once at the start
 
-diff = config_diff_class(explain, dump_config, dump_diff, debug_convert)
+diff = config_diff_class(
+           explain, dump_config, dump_diff, debug_convert, subtree_dump_filter)
 
 
 # if a rules tree file was specified, read that in
@@ -382,7 +392,8 @@ if rules_tree_filename:
 
 if dump_rules >= 1:
     print(">> rule tree:")
-    print(yaml.dump(diff.get_rules_tree(), default_flow_style=False))
+    print(yaml.dump(deepget(diff.get_rules_tree(), *subtree_dump_filter),
+                    default_flow_style=False))
     print(">> rule specs:")
     for spec in rule_specs:
         print("->", spec)
